var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import prompts from 'prompts';
import { getMdAction, changePathAction, changeAbsolutePathAction, changesuffixAction, markFileAction, witeFileAction, deletMarkAction, renameFoldAction, renameFileAction } from './command-actions';
import { VERSION, PKG_NAME } from '../shared/constant';
import help from '../../script/help/index';
import stringToArgs from '../../script/cli';
import { wirteJsNodes } from './change-path';
import { getMd } from './wirte-md';
import handle from '../../script/cli/handle';
import { createConsola } from 'consola';
const logger = createConsola({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
const options = stringToArgs(process.argv);
const { ignores: ignore, includes: include } = handle(options);
export function selectCommand() {
    return __awaiter(this, void 0, void 0, function* () {
        const actionMap = new Map();
        const { md, nodes } = yield getMd({ ignore, include });
        actionMap.set('help', {
            title: '🙏  帮助',
            value: 'help',
            selected: true,
            action: () => help()
        });
        actionMap.set('Generate MD', {
            title: '📅  生成结构树文档',
            value: 'Generate MD',
            selected: true,
            action: () => getMdAction(md)
        });
        actionMap.set('Change Relative Path', {
            title: '🔑  修改为相当路径',
            value: 'Change Relative Path',
            action: () => changePathAction(nodes)
        });
        actionMap.set('Change Absolute  Path', {
            title: '💎  修改为绝对路径(暂未实现)',
            value: 'Change Absolute  Path',
            action: () => changeAbsolutePathAction()
        });
        actionMap.set('Completion suffix', {
            title: '💯  补全文件后缀',
            value: 'Completion suffix',
            action: () => changesuffixAction(nodes, true)
        });
        actionMap.set('RenameFoldKebabCase', {
            title: '🎁  统一命名文件夹为KebabCase',
            value: 'RenameFoldKebabCase',
            action: () => renameFoldAction(nodes)
        });
        actionMap.set('RenameFielKebabCase', {
            title: '🍰  统一命名文件为KebabCase',
            value: 'RenameFielKebabCase',
            action: () => renameFileAction(nodes)
        });
        actionMap.set('Wirte Json Nodes', {
            title: '🔱  记录节点Json',
            value: 'Wirte Json Nodes',
            action: () => wirteJsNodes(JSON.stringify(nodes), rootPath + '/readme-file.js')
        });
        actionMap.set('Mark File', {
            title: '🎊  给需要分类的都打上标记',
            value: 'Mark File',
            action: () => markFileAction(nodes)
        });
        actionMap.set('Delete Mark', {
            title: '💥  删除标记',
            value: 'Delete Mark',
            action: () => deletMarkAction(nodes)
        });
        actionMap.set('Classification', {
            title: '💫  分类',
            value: 'Classification',
            action: () => witeFileAction(nodes)
        });
        return actionMap;
    });
}
export function handleCommand(cmd) {
    return __awaiter(this, void 0, void 0, function* () {
        if (cmd.init) {
            logger.info(`${PKG_NAME}:version is :${VERSION}`);
        }
        const actions = yield selectCommand();
        let result = {};
        try {
            result = yield prompts([
                {
                    name: 'command',
                    type: 'select',
                    message: '请使用上下键选择一个操作命令：',
                    choices: Array.from(actions.values())
                }
            ], {
                onCancel: () => {
                    throw new Error('操作取消！');
                }
            });
        }
        catch (e) {
            logger.error(e.message);
            process.exit(1);
        }
        actions.get(result.command).action();
    });
}
//# sourceMappingURL=command-handler.js.map