var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { readdir, readFile, stat, access } from 'fs/promises';
import { createConsola } from 'consola';
import path from 'path';
import { parseRouterPath, parseComponentPath } from '../utils/router-utils';
const logger = createConsola({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
export function getRouterFilePath(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const routes = [];
        function finder(p) {
            return __awaiter(this, void 0, void 0, function* () {
                const files = yield readdir(p);
                for (const val of files) {
                    const fPath = path.join(p, val).replace(/\\/g, '/');
                    const stats = yield stat(fPath);
                    if (stats.isDirectory()) {
                        yield finder(fPath);
                    }
                    else if (stats.isFile()) {
                        routes.push(fPath);
                    }
                }
            });
        }
        yield finder(dir);
        return routes;
    });
}
export function getAllRouter(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const filePaths = yield getRouterFilePath(dir);
        const routers = [];
        for (const filePath of filePaths) {
            const routerItems = yield getRouter(filePath);
            routers.push(...routerItems);
        }
        return routers;
    });
}
export function getRouter(routerPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const routers = [];
        try {
            yield access(routerPath);
            const fileContent = yield readFile(routerPath, 'utf-8');
            const lines = fileContent.split(/\n/g);
            let currentPath = '';
            let currentComponent = '';
            lines.forEach((line) => {
                if (line.includes('//'))
                    return;
                const tempPath = parseRouterPath(line);
                if (tempPath)
                    currentPath = tempPath;
                const tempComponent = parseComponentPath(line);
                if (tempComponent)
                    currentComponent = tempComponent;
                if (currentPath && currentComponent) {
                    routers.push({ path: currentPath, component: currentComponent });
                    currentPath = '';
                    currentComponent = '';
                }
            });
        }
        catch (error) {
            console.error('读取路由配置时出错:', error);
        }
        return routers;
    });
}
export function getRouterArrs() {
    return __awaiter(this, void 0, void 0, function* () {
        const pathName = `${rootPath}/classify.js`;
        const dir = `${rootPath}/router`;
        let routers = null;
        try {
            if (yield stat(pathName)) {
                routers = yield import(pathName);
            }
            else {
                routers = [
                    {
                        name: 'mark',
                        router: yield getAllRouter(dir)
                    }
                ];
            }
        }
        catch (error) {
            logger.error('根路径没有发现 classify.js，并且 src 里面没有 router 文件，现在退出');
            process.exit(1);
        }
        return routers;
    });
}
//# sourceMappingURL=get-router.js.map