var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import fs from 'fs';
import { readFile, writeFile } from 'fs/promises';
import { markWriteFile } from './mark-write-file';
import { createConsola } from 'consola';
const logger = createConsola({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
export function markFile(nodes, routers) {
    return __awaiter(this, void 0, void 0, function* () {
        for (let i = 0; i < routers.length; i++) {
            const ele = routers[i];
            for (let j = 0; j < ele.router.length; j++) {
                const obj = ele.router[j];
                const pathN = obj.component;
                logger.info(`准备处理${obj.path}`);
                const absolutePath = pathN.replace('@', rootPath);
                yield setNodeMark(nodes, ele.name, absolutePath);
            }
        }
    });
}
export function witeMarkFile(nodes, routers) {
    return __awaiter(this, void 0, void 0, function* () {
        for (let index = 0; index < routers.length; index++) {
            const ele = routers[index];
            for (let j = 0; j < ele.router.length; j++) {
                const obj = ele.router[j];
                const pathN = obj.component;
                const absolutePath = pathN.replace('@', rootPath);
                yield markWriteFile(nodes, ele.name, absolutePath);
            }
        }
    });
}
export function setNodeMark(nodes, name, path) {
    return __awaiter(this, void 0, void 0, function* () {
        logger.info('setNodeMark入参: ', name, path);
        const node = findNodes(nodes, path);
        if (node) {
            yield setmark(path, name);
        }
        if (node && node.imports) {
            if (node.belongTo.indexOf(name) > -1)
                return;
            node.belongTo.push(name);
            for (let index = 0; index < node.imports.length; index++) {
                const element = node.imports[index];
                if (fs.existsSync(path)) {
                    yield setNodeMark(nodes, name, element);
                }
                else {
                    logger.error(`文件不存在: ${path}`);
                }
            }
        }
    });
}
export function findNodes(nodes, path) {
    let node = null;
    function find(objs) {
        for (let index = 0; index < objs.length; index++) {
            const element = objs[index];
            if (element.children)
                find(element.children);
            if (element.fullPath === path)
                node = element;
        }
    }
    find(nodes);
    return node;
}
export function setmark(file, name) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            let fileStr = yield readFile(file, 'utf-8');
            const mark = `//${name}\n`;
            if (!fileStr.startsWith(mark)) {
                fileStr = mark + fileStr;
                yield writeFile(file, fileStr);
                logger.info(`Mark added successfully to: ${file}`);
            }
        }
        catch (error) {
            logger.error(`Error marking file: ${file}, Error: ${error}`);
        }
    });
}
export function deletMarkAll(nodes, name) {
    return __awaiter(this, void 0, void 0, function* () {
        function find(objs) {
            return __awaiter(this, void 0, void 0, function* () {
                for (let index = 0; index < objs.length; index++) {
                    const element = objs[index];
                    if (element.children)
                        find(element.children);
                    else
                        yield deletMark(element.fullPath, name);
                }
            });
        }
        yield find(nodes);
    });
}
export function deletMark(file, name) {
    return __awaiter(this, void 0, void 0, function* () {
        let fileStr = '';
        try {
            fileStr = yield readFile(file, 'utf-8');
            const sarr = fileStr.split(/[\n]/g);
            for (let index = 0; index < sarr.length; index++) {
                const ele = sarr[index];
                if (ele.indexOf('//' + name) > -1) {
                    sarr.splice(index, 1);
                    index--;
                }
            }
            fileStr = sarr.join('\n');
            yield writeFile(file, fileStr, { encoding: 'utf8' });
            logger.success('delete mark successful-------' + file);
            return fileStr;
        }
        catch (error) {
            logger.error('删除标记的文件不存在: ', file);
        }
        return '';
    });
}
//# sourceMappingURL=mark-file.js.map