"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wirteJsNodes = exports.writeToFile = exports.changeImport = exports.getImportName = exports.makeSuffix = exports.getRelatPath = exports.changePath = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const promises_1 = require("fs/promises");
const consola_1 = require("consola");
const router_utils_1 = require("../utils/router-utils");
const logger = (0, consola_1.createConsola)({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
function changePath(nodes, nochangePath) {
    return __awaiter(this, void 0, void 0, function* () {
        function getNode(objs) {
            return __awaiter(this, void 0, void 0, function* () {
                for (const ele of objs) {
                    if (ele.children) {
                        yield getNode(ele.children);
                    }
                    else {
                        yield writeToFile(ele, true, nochangePath);
                    }
                }
            });
        }
        yield getNode(nodes);
    });
}
exports.changePath = changePath;
function getRelatPath(absoluteImport, fullPath) {
    let relatPath = path_1.default.relative(path_1.default.dirname(fullPath), absoluteImport).replace(/\\/g, '/');
    if (!relatPath.startsWith('.')) {
        relatPath = './' + relatPath;
    }
    return relatPath;
}
exports.getRelatPath = getRelatPath;
function makeSuffix(filePath, fullPath) {
    let absoluteImport = filePath.includes('@')
        ? filePath.replace('@', process.cwd())
        : path_1.default.resolve(path_1.default.dirname(fullPath), filePath);
    const lastName = path_1.default.extname(absoluteImport);
    if (!lastName) {
        const suffixes = ['.ts', '.vue', '.tsx', '.js', '/index.js', '/index.vue'];
        for (const suffix of suffixes) {
            if (fs_1.default.existsSync(absoluteImport + suffix)) {
                absoluteImport += suffix;
                logger.info('补充后缀:', absoluteImport + suffix);
                break;
            }
        }
    }
    return absoluteImport.replace(/\\/g, '/');
}
exports.makeSuffix = makeSuffix;
function getImportName(ele, dependencies) {
    let str = '';
    const flag = dependencies.some((item) => ele.indexOf(item) > -1);
    const reg = / from [\"|\'](.*)[\'|\"]/;
    if (!flag && ele.indexOf('/') > -1 && ele.indexOf('//') !== 0) {
        const impStr = ele.match(reg);
        if (impStr && impStr[1])
            str = impStr[1];
    }
    return str;
}
exports.getImportName = getImportName;
function changeImport(ele, fullPath, dependencies, nochangePath) {
    const impName = getImportName(ele, dependencies);
    if (!impName)
        return null;
    const absoluteImport = makeSuffix(impName, fullPath);
    const obj = {
        impName: nochangePath ? impName : getRelatPath(absoluteImport, fullPath),
        filePath: impName,
        absoluteImport
    };
    return obj;
}
exports.changeImport = changeImport;
function writeToFile(node, isRelative, nochangePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const { fullPath } = node;
        const packageJsonPath = path_1.default.join(rootPath, 'package.json');
        const dependencies = yield (0, router_utils_1.getDependencies)(packageJsonPath);
        try {
            const fileStr = yield (0, promises_1.readFile)(fullPath, 'utf-8');
            const lines = fileStr.split(/[\n]/g);
            const updatedLines = lines.map((line) => {
                if (line.includes('from') && isRelative) {
                    const obj = changeImport(line, fullPath, dependencies, nochangePath);
                    if (obj && obj.impName) {
                        logger.info(`Updating import in node: ${node}`);
                        return line.replace(obj.filePath, obj.impName);
                    }
                }
                return line;
            });
            if (updatedLines.join('\n') !== fileStr) {
                yield (0, promises_1.writeFile)(fullPath, updatedLines.join('\n'), 'utf-8');
                logger.success(`Write file successful: ${fullPath}`);
            }
        }
        catch (error) {
            logger.error(`Error reading file: ${fullPath}, Error: ${error}`);
        }
    });
}
exports.writeToFile = writeToFile;
function wirteJsNodes(data, filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const file = path_1.default.resolve(rootPath, filePath);
        const content = `export default ${data}`;
        yield (0, promises_1.writeFile)(file, content, { encoding: 'utf8' });
        logger.success(`Write file successful: ${filePath}`);
    });
}
exports.wirteJsNodes = wirteJsNodes;
//# sourceMappingURL=change-path.js.map