"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleCommand = exports.selectCommand = void 0;
const prompts_1 = __importDefault(require("prompts"));
const command_actions_1 = require("./command-actions");
const constant_1 = require("../shared/constant");
const index_1 = __importDefault(require("../../script/help/index"));
const cli_1 = __importDefault(require("../../script/cli"));
const change_path_1 = require("./change-path");
const wirte_md_1 = require("./wirte-md");
const handle_1 = __importDefault(require("../../script/cli/handle"));
const consola_1 = require("consola");
const logger = (0, consola_1.createConsola)({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
const options = (0, cli_1.default)(process.argv);
const { ignores: ignore, includes: include } = (0, handle_1.default)(options);
function selectCommand() {
    return __awaiter(this, void 0, void 0, function* () {
        const actionMap = new Map();
        const { md, nodes } = yield (0, wirte_md_1.getMd)({ ignore, include });
        actionMap.set('help', {
            title: '🙏  帮助',
            value: 'help',
            selected: true,
            action: () => (0, index_1.default)()
        });
        actionMap.set('Generate MD', {
            title: '📅  生成结构树文档',
            value: 'Generate MD',
            selected: true,
            action: () => (0, command_actions_1.getMdAction)(md)
        });
        actionMap.set('Change Relative Path', {
            title: '🔑  修改为相当路径',
            value: 'Change Relative Path',
            action: () => (0, command_actions_1.changePathAction)(nodes)
        });
        actionMap.set('Change Absolute  Path', {
            title: '💎  修改为绝对路径(暂未实现)',
            value: 'Change Absolute  Path',
            action: () => (0, command_actions_1.changeAbsolutePathAction)()
        });
        actionMap.set('Completion suffix', {
            title: '💯  补全文件后缀',
            value: 'Completion suffix',
            action: () => (0, command_actions_1.changesuffixAction)(nodes, true)
        });
        actionMap.set('RenameFoldKebabCase', {
            title: '🎁  统一命名文件夹为KebabCase',
            value: 'RenameFoldKebabCase',
            action: () => (0, command_actions_1.renameFoldAction)(nodes)
        });
        actionMap.set('RenameFielKebabCase', {
            title: '🍰  统一命名文件为KebabCase',
            value: 'RenameFielKebabCase',
            action: () => (0, command_actions_1.renameFileAction)(nodes)
        });
        actionMap.set('Wirte Json Nodes', {
            title: '🔱  记录节点Json',
            value: 'Wirte Json Nodes',
            action: () => (0, change_path_1.wirteJsNodes)(JSON.stringify(nodes), rootPath + '/readme-file.js')
        });
        actionMap.set('Mark File', {
            title: '🎊  给需要分类的都打上标记',
            value: 'Mark File',
            action: () => (0, command_actions_1.markFileAction)(nodes)
        });
        actionMap.set('Delete Mark', {
            title: '💥  删除标记',
            value: 'Delete Mark',
            action: () => (0, command_actions_1.deletMarkAction)(nodes)
        });
        actionMap.set('Classification', {
            title: '💫  分类',
            value: 'Classification',
            action: () => (0, command_actions_1.witeFileAction)(nodes)
        });
        return actionMap;
    });
}
exports.selectCommand = selectCommand;
function handleCommand(cmd) {
    return __awaiter(this, void 0, void 0, function* () {
        if (cmd.init) {
            logger.info(`${constant_1.PKG_NAME}:version is :${constant_1.VERSION}`);
        }
        const actions = yield selectCommand();
        let result = {};
        try {
            result = yield (0, prompts_1.default)([
                {
                    name: 'command',
                    type: 'select',
                    message: '请使用上下键选择一个操作命令：',
                    choices: Array.from(actions.values())
                }
            ], {
                onCancel: () => {
                    throw new Error('操作取消！');
                }
            });
        }
        catch (e) {
            logger.error(e.message);
            process.exit(1);
        }
        actions.get(result.command).action();
    });
}
exports.handleCommand = handleCommand;
//# sourceMappingURL=command-handler.js.map