"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setMd = exports.getNote = exports.getFileNodes = exports.getImport = exports.getFile = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const promises_1 = require("fs/promises");
const change_path_1 = require("./change-path");
const router_utils_1 = require("../utils/router-utils");
const rootPath = process.cwd().replace(/\\/g, '/');
const ignore = [
    'es6',
    'lib',
    'jest.config.js',
    'router',
    'img',
    'styles',
    'node_modules',
    'LICENSE',
    '.git',
    '.github',
    'dist',
    '.husky',
    '.vscode',
    '.eslintrc.js',
    'readme-file.js',
    'readme-md.js'
];
function getFile(fullPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const str = yield (0, promises_1.readFile)(fullPath, 'utf-8');
        const size = str.length;
        const sarr = str.split(/[\n]/g);
        const rowSize = sarr.length;
        const imports = yield getImport(sarr, fullPath);
        const f = sarr[0].indexOf('eslint') === -1 &&
            (sarr[0].indexOf('-->') > -1 || sarr[0].indexOf('*/') > -1 || sarr[0].indexOf('//') > -1)
            ? sarr[0]
            : '';
        return {
            note: f.replace(/<\/?[^>]*>|(\n|\r)/g, ''),
            size,
            rowSize,
            imports
        };
    });
}
exports.getFile = getFile;
function getImport(sarr, fullPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const packageJsonPath = path_1.default.join(rootPath, 'package.json');
        const dependencies = yield (0, router_utils_1.getDependencies)(packageJsonPath);
        const imports = [];
        sarr.forEach((ele) => {
            if (ele.indexOf('from') > -1) {
                const obj = (0, change_path_1.changeImport)(ele, fullPath, dependencies);
                if (obj) {
                    const { absoluteImport } = obj;
                    if (absoluteImport) {
                        imports.push(absoluteImport);
                    }
                }
            }
        });
        return imports;
    });
}
exports.getImport = getImport;
function getFileInfo(dir, item, level) {
    const fullPath = path_1.default.join(dir, item);
    const isDir = fs_1.default.lstatSync(fullPath).isDirectory();
    return {
        name: item,
        isDir,
        level,
        note: '',
        imports: new Array(),
        belongTo: new Array()
    };
}
function sortFiles(files) {
    return files.sort((a, b) => {
        if (!a.isDir && b.isDir)
            return 1;
        if (a.isDir && !b.isDir)
            return -1;
        return 0;
    });
}
function handleDirectory(dir, item, option, level, nodes) {
    return __awaiter(this, void 0, void 0, function* () {
        yield getFileNodes(path_1.default.join(dir, item.name), option, (item.children = []), level + 1);
        item.fullPath = path_1.default.join(dir, item.name).replace(/\\/g, '/');
        nodes.push(item);
    });
}
function handleFile(dir, item, include, nodes) {
    return __awaiter(this, void 0, void 0, function* () {
        const fullPath = path_1.default.join(dir, item.name);
        const suffix = path_1.default.extname(fullPath);
        if (include.includes(suffix)) {
            const obj = yield getFile(fullPath);
            Object.assign(item, obj);
            item.suffix = suffix;
            item.fullPath = fullPath.replace(/\\/g, '/');
            nodes.push(item);
        }
    });
}
function getFileNodes(dir = process.cwd(), option, nodes = [], level = 0) {
    return __awaiter(this, void 0, void 0, function* () {
        let include = ['.js', '.vue', '.ts', '.tsx'];
        let finalIgnore = ignore;
        if (option) {
            finalIgnore = option.ignore || ignore;
            include = option.include || include;
        }
        const files = yield (0, promises_1.readdir)(dir);
        const tempFiles = yield Promise.all(files.map((item) => getFileInfo(dir, item, level)));
        sortFiles(tempFiles);
        for (const item of tempFiles) {
            if (!finalIgnore.includes(item.name)) {
                if (item.isDir) {
                    yield handleDirectory(dir, item, option, level, nodes);
                }
                else {
                    yield handleFile(dir, item, include, nodes);
                }
            }
        }
        return nodes;
    });
}
exports.getFileNodes = getFileNodes;
function getNote(datas, keys) {
    const nodes = keys || [];
    for (let index = 0; index < datas.length; index++) {
        const obj = datas[index];
        const last = index === datas.length - 1;
        const md = setMd(obj, last);
        nodes.push(md);
        if (obj.children) {
            getNote(obj.children, nodes);
        }
    }
    return nodes;
}
exports.getNote = getNote;
function setMd(obj, last) {
    let filesString = '';
    const blank = '│ '.repeat(obj.level);
    const pre = `${blank}${last ? '└──' : '├──'} ${obj.name}`;
    if (obj.isDir) {
        filesString += `${pre}\n`;
    }
    else {
        filesString += `${pre}            ${obj.note}\n`;
    }
    return filesString;
}
exports.setMd = setMd;
//# sourceMappingURL=get-file.js.map