"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deletMark = exports.deletMarkAll = exports.setmark = exports.findNodes = exports.setNodeMark = exports.witeMarkFile = exports.markFile = void 0;
const fs_1 = __importDefault(require("fs"));
const promises_1 = require("fs/promises");
const mark_write_file_1 = require("./mark-write-file");
const consola_1 = require("consola");
const logger = (0, consola_1.createConsola)({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
function markFile(nodes, routers) {
    return __awaiter(this, void 0, void 0, function* () {
        for (let i = 0; i < routers.length; i++) {
            const ele = routers[i];
            for (let j = 0; j < ele.router.length; j++) {
                const obj = ele.router[j];
                const pathN = obj.component;
                logger.info(`准备处理${obj.path}`);
                const absolutePath = pathN.replace('@', rootPath);
                yield setNodeMark(nodes, ele.name, absolutePath);
            }
        }
    });
}
exports.markFile = markFile;
function witeMarkFile(nodes, routers) {
    return __awaiter(this, void 0, void 0, function* () {
        for (let index = 0; index < routers.length; index++) {
            const ele = routers[index];
            for (let j = 0; j < ele.router.length; j++) {
                const obj = ele.router[j];
                const pathN = obj.component;
                const absolutePath = pathN.replace('@', rootPath);
                yield (0, mark_write_file_1.markWriteFile)(nodes, ele.name, absolutePath);
            }
        }
    });
}
exports.witeMarkFile = witeMarkFile;
function setNodeMark(nodes, name, path) {
    return __awaiter(this, void 0, void 0, function* () {
        logger.info('setNodeMark入参: ', name, path);
        const node = findNodes(nodes, path);
        if (node) {
            yield setmark(path, name);
        }
        if (node && node.imports) {
            if (node.belongTo.indexOf(name) > -1)
                return;
            node.belongTo.push(name);
            for (let index = 0; index < node.imports.length; index++) {
                const element = node.imports[index];
                if (fs_1.default.existsSync(path)) {
                    yield setNodeMark(nodes, name, element);
                }
                else {
                    logger.error(`文件不存在: ${path}`);
                }
            }
        }
    });
}
exports.setNodeMark = setNodeMark;
function findNodes(nodes, path) {
    let node = null;
    function find(objs) {
        for (let index = 0; index < objs.length; index++) {
            const element = objs[index];
            if (element.children)
                find(element.children);
            if (element.fullPath === path)
                node = element;
        }
    }
    find(nodes);
    return node;
}
exports.findNodes = findNodes;
function setmark(file, name) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            let fileStr = yield (0, promises_1.readFile)(file, 'utf-8');
            const mark = `//${name}\n`;
            if (!fileStr.startsWith(mark)) {
                fileStr = mark + fileStr;
                yield (0, promises_1.writeFile)(file, fileStr);
                logger.info(`Mark added successfully to: ${file}`);
            }
        }
        catch (error) {
            logger.error(`Error marking file: ${file}, Error: ${error}`);
        }
    });
}
exports.setmark = setmark;
function deletMarkAll(nodes, name) {
    return __awaiter(this, void 0, void 0, function* () {
        function find(objs) {
            return __awaiter(this, void 0, void 0, function* () {
                for (let index = 0; index < objs.length; index++) {
                    const element = objs[index];
                    if (element.children)
                        find(element.children);
                    else
                        yield deletMark(element.fullPath, name);
                }
            });
        }
        yield find(nodes);
    });
}
exports.deletMarkAll = deletMarkAll;
function deletMark(file, name) {
    return __awaiter(this, void 0, void 0, function* () {
        let fileStr = '';
        try {
            fileStr = yield (0, promises_1.readFile)(file, 'utf-8');
            const sarr = fileStr.split(/[\n]/g);
            for (let index = 0; index < sarr.length; index++) {
                const ele = sarr[index];
                if (ele.indexOf('//' + name) > -1) {
                    sarr.splice(index, 1);
                    index--;
                }
            }
            fileStr = sarr.join('\n');
            yield (0, promises_1.writeFile)(file, fileStr, { encoding: 'utf8' });
            logger.success('delete mark successful-------' + file);
            return fileStr;
        }
        catch (error) {
            logger.error('删除标记的文件不存在: ', file);
        }
        return '';
    });
}
exports.deletMark = deletMark;
//# sourceMappingURL=mark-file.js.map