"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceName = exports.renameFile = exports.changePathName = exports.changePathFold = exports.renameFold = exports.renameFilePath = exports.renameFoldPath = exports.checkCamelFile = exports.toKebabCase = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const promises_1 = require("fs/promises");
const path_1 = __importDefault(require("path"));
const consola_1 = require("consola");
const router_utils_1 = require("../utils/router-utils");
const change_path_1 = require("./change-path");
const logger = (0, consola_1.createConsola)({
    level: 4
});
const rootPath = process.cwd().replace(/\\/g, '/');
function fistLetterLower(str) {
    return str.charAt(0).toLowerCase() + str.slice(1);
}
function toKebabCase(str) {
    const regex = /[A-Z]/g;
    return fistLetterLower(str).replace(regex, (word) => {
        return '-' + word.toLowerCase();
    });
}
exports.toKebabCase = toKebabCase;
function checkCamelFile(fileName) {
    return /([a-z])([A-Z])/.test(fileName) || /([A-Z])/.test(fileName);
}
exports.checkCamelFile = checkCamelFile;
function renameFoldPath(nodes) {
    return __awaiter(this, void 0, void 0, function* () {
        function getNode(cpNodes) {
            return __awaiter(this, void 0, void 0, function* () {
                for (let index = 0; index < cpNodes.length; index++) {
                    const ele = cpNodes[index];
                    yield renameFold(ele);
                    if (ele.children) {
                        yield getNode(ele.children);
                    }
                }
            });
        }
        yield getNode(nodes);
    });
}
exports.renameFoldPath = renameFoldPath;
function renameFilePath(nodes) {
    return __awaiter(this, void 0, void 0, function* () {
        function getNode(cpNodes) {
            return __awaiter(this, void 0, void 0, function* () {
                for (let index = 0; index < cpNodes.length; index++) {
                    const ele = cpNodes[index];
                    if (ele.children) {
                        yield getNode(ele.children);
                    }
                    else {
                        yield renameFile(ele);
                        yield rewriteFile(ele);
                    }
                }
            });
        }
        yield getNode(nodes);
    });
}
exports.renameFilePath = renameFilePath;
function rewriteFile(node) {
    return __awaiter(this, void 0, void 0, function* () {
        let writeFlag = false;
        const str = yield (0, promises_1.readFile)(node.fullPath, 'utf-8');
        const sarr = str.split(/[\n]/g);
        const packageJsonPath = path_1.default.join(rootPath, 'package.json');
        const dependencies = yield (0, router_utils_1.getDependencies)(packageJsonPath);
        for (let index = 0; index < sarr.length; index++) {
            const ele = sarr[index];
            if (ele.indexOf('from') > -1) {
                const impOldName = (0, change_path_1.getImportName)(ele, dependencies);
                if (checkCamelFile(impOldName)) {
                    const name = path_1.default.parse(impOldName).name;
                    const newName = toKebabCase(name);
                    const s = ele.split('from');
                    sarr[index] = `${s[0]}from${s[1].replace(name, newName)}`;
                    writeFlag = true;
                }
            }
        }
        if (writeFlag) {
            const fileStr = sarr.join('\n');
            try {
                yield fs_extra_1.default.writeFile(node.fullPath, fileStr, { encoding: 'utf8' });
                logger.success(`rewriteFile successful-------: ${node.fullPath}`);
            }
            catch (error) {
                logger.error(`写入文件失败,地址不存在: ${node.fullPath}`);
            }
        }
    });
}
function renameFold(node) {
    return __awaiter(this, void 0, void 0, function* () {
        const filename = path_1.default.parse(node.fullPath).base;
        logger.info('filename111: ', filename);
        const filter = ['FMEA', 'DVP'];
        const falg = filter.some((item) => filename.indexOf(item) > -1);
        if (!falg && checkCamelFile(filename)) {
            if (node.isDir) {
                const obj = yield replaceName(node.fullPath);
                changePathFold(node, obj);
            }
        }
    });
}
exports.renameFold = renameFold;
function changePathFold(node, obj) {
    const { newName, filename } = obj;
    if (node.children) {
        for (let index = 0; index < node.children.length; index++) {
            const ele = node.children[index];
            changePathFold(ele, obj);
        }
    }
    node.fullPath = node.fullPath.replace(filename, newName);
    logger.info(node.fullPath, newName);
    node.name = node.name.replace(filename, newName);
}
exports.changePathFold = changePathFold;
function changePathName(node, obj) {
    const { newName, filename } = obj;
    if (node.fullPath.indexOf(filename) > -1) {
        if (node.imports.length > 0) {
            const array = node.imports;
            for (let j = 0; j < array.length; j++) {
                const ele = array[j];
                logger.info('import-ele: ', ele);
                array[j] = toKebabCase(ele);
                logger.info('更换import: ', array[j]);
            }
        }
        node.fullPath = node.fullPath.replace(filename, newName);
        node.name = node.name.replace(filename, newName);
        logger.success('替换后的 node.fullPath:', node.fullPath);
    }
}
exports.changePathName = changePathName;
function renameFile(node) {
    return __awaiter(this, void 0, void 0, function* () {
        const filename = path_1.default.parse(node.fullPath).base;
        if (checkCamelFile(filename)) {
            const suffix = ['.js', '.vue', '.tsx'];
            const lastName = path_1.default.extname(node.fullPath);
            const flag = suffix.some((item) => lastName === item);
            if (flag) {
                const obj = yield replaceName(node.fullPath);
                changePathName(node, obj);
            }
        }
    });
}
exports.renameFile = renameFile;
function replaceName(fullPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const filename = path_1.default.parse(fullPath).base;
        const newName = toKebabCase(filename);
        const oldPath = fullPath;
        const newPath = oldPath.replace(filename, newName);
        const lastName = path_1.default.extname(newPath);
        if (!lastName) {
            if (fs_extra_1.default.existsSync(newPath)) {
                yield fs_extra_1.default.copy(fullPath, newPath);
                fs_extra_1.default.removeSync(fullPath);
                return { newName, filename };
            }
        }
        try {
            const flag = fs_extra_1.default.existsSync(oldPath);
            if (flag) {
                yield fs_extra_1.default.rename(oldPath, newPath);
                logger.success(oldPath, '改名为: ', newPath);
            }
            else {
                logger.error(`文件${oldPath}不存在重命名干嘛?`);
            }
            logger.info(filename + ' is reneme done');
            return { newName, filename };
        }
        catch (error) {
            throw error;
        }
    });
}
exports.replaceName = replaceName;
//# sourceMappingURL=rename-path.js.map